@@ -234,10 +234,6 @@ octave_value_list do_filtering (const MT &A, const boolNDArray &dom,
   for (octave_idx_type i = 0; i < dom_numel; i++)
     len += dom (i);
 
-  dim_vector dim_offset (dom_size);
-  for (int i = 0; i < ndims; i++)
-    dim_offset (i) = (dom_size (i)+1) / 2 - 1;
-
   // Allocate output
   dim_vector out_size (dom_size);
   for (int i = 0; i < ndims; i++)
@@ -247,14 +243,12 @@ octave_value_list do_filtering (const MT &A, const boolNDArray &dom,
   const octave_idx_type out_numel = out.numel ();
 
   // Iterate over every element of 'out'.
-  dim_vector idx_dim (ndims);
+  dim_vector idx_dim (ndims, 1);
   Array<octave_idx_type> dom_idx (idx_dim);
   Array<octave_idx_type> A_idx (idx_dim);
   Array<octave_idx_type> out_idx (idx_dim, 0);
   
-  dim_vector values_size (2);
-  values_size (0) = 1;
-  values_size (1) = len;
+  dim_vector values_size (1, len);
   MT values (values_size);
   
   for (octave_idx_type i = 0; i < out_numel; i++)
